@@ -179,7 +179,9 @@ impl Slack {
         let t: AccessToken = resp.json().await.unwrap();
 
         self.token = t.access_token.to_string();
-        self.user_token = t.authed_user.access_token.to_string();
+        if let Some(ref user) = t.authed_user {
+            self.user_token = user.access_token.to_string();
+        }
 
         Ok(t)
     }
@@ -713,12 +715,12 @@ pub struct AccessToken {
     pub app_id: String,
     #[serde(default)]
     pub team: Team,
-    #[serde(default)]
-    pub enterprise: Enterprise,
-    #[serde(default)]
-    pub authed_user: AuthedUser,
-    #[serde(default)]
-    pub incoming_webhook: IncomingWebhook,
+    #[serde(default, skip_serializing_if = "Option::is_none")]
+    pub enterprise: Option<Enterprise>,
+    #[serde(default, skip_serializing_if = "Option::is_none")]
+    pub authed_user: Option<AuthedUser>,
+    #[serde(default, skip_serializing_if = "Option::is_none")]
+    pub incoming_webhook: Option<IncomingWebhook>,
 }
 
 #[derive(Debug, JsonSchema, Clone, Default, Serialize, Deserialize)]
